@@ -6,37 +6,58 @@ import logging
 from .exceptions import ScraperException
 
 SELF_DIR = os.path.dirname(os.path.abspath(__file__))
+NODE_DIR = os.path.join(SELF_DIR, 'node_modules', 'google-play-scraper')
 logger = logging.getLogger('__main__')
 
 # Private module class.
 class _Wrapper:
 
-    require_dir = os.path.join(SELF_DIR, 'node_modules', 'google-play-scraper')
+    node_dir = [x if x != '' else os.path.sep for x in NODE_DIR.split(os.path.sep)]
+    require_dir = "'{}'".format("', '".join(node_dir))
 
+    init_script = "var gplay = require(path.join({}));"
     api_script = (
-        "var gplay = require('{}'){};"
+        "var gplay = require(path.join({})){};"
         "gplay.{}({{{}}})"
         ".then(JSON.stringify).then(console.log).catch(console.log);"
     )
-
     var_script = (
-        "var gplay = require('{}'){};"
+        "var gplay = require(path.join({})){};"
         "let x = gplay.{};"
         "console.log(JSON.stringify(x));"
     )
 
-    def __init__(self, memoization=False, vars=[]):
+    def __init__(self, memoization=False):
         self.memoization = '.memoized()' if memoization else ''
+
+    def check_modules(self):
+        args = ['node', '-e', self.init_script.format(self.require_dir)]
+        try:
+            subprocess.run(args, capture_output=True, check=True)
+        except subprocess.CalledProcessError as e:
+            stderr = e.stderr.decode()
+            if 'Error: Cannot find module' in stderr:
+                return False
+            raise ScraperException(stderr) from None
+        return True
+
+    def update_modules(self):
+        install_args = ['npm', '--prefix', SELF_DIR, 'update']
+        return subprocess.run(install_args, capture_output=True, check=True)
+
+    def set_vars(self, vars=[]):
         for var in vars:
             setattr(_Wrapper, var, self._execute_var(var))
 
     def _execute_api(self, fn_name, keys, **kwargs):
         cmd = self._get_args(keys, **kwargs)
-        script = self.api_script.format(self.require_dir, self.memoization, fn_name, cmd)
+        script = self.api_script.format(
+            self.require_dir, self.memoization, fn_name, cmd)
         return self._execute(script)
 
     def _execute_var(self, var_name):
-        script = self.var_script.format(self.require_dir, self.memoization, var_name)
+        script = self.var_script.format(
+            self.require_dir, self.memoization, var_name)
         return self._execute(script)
 
     def _execute(self, script):
@@ -50,7 +71,7 @@ class _Wrapper:
         stdout = process.stdout.decode()
         try:
             return json.loads(stdout)
-        except json.decoder.JSONDecodeError as e:
+        except json.decoder.JSONDecodeError:
             raise ScraperException(stdout) from None
 
     def _get_args(self, keys, **kwargs):
@@ -63,11 +84,17 @@ class _Wrapper:
                 return '{}'.format(str(x).lower())
             return '{}'.format(x)
 
-        args = ', '.join(["{}: {}".format(k, stringify(v)) for k, v in kwargs.items() if k in keys + ['throttle']])
+        args = ', '.join(["{}: {}".format(k, stringify(v))
+                          for k, v in kwargs.items() if k in keys + ['throttle']])
         return args
 
+
 # Private module attributes.
-_wrapper = _Wrapper(vars=['collection', 'category', 'age', 'sort'])
+_wrapper = _Wrapper()
+_wrapper.update_modules()
+
+# Set wrapper fields.
+_wrapper.set_vars(vars=['collection', 'category', 'age', 'sort'])
 
 # Public module attributes.
 collection = _wrapper.collection
@@ -81,6 +108,7 @@ def app(appId, **kwargs):
     output = _wrapper._execute_api('app', keys, **{'appId': appId, **kwargs})
     return output
 
+
 def list(**kwargs):
     keys = [
         'collection', 'category', 'age', 'num',
@@ -89,6 +117,7 @@ def list(**kwargs):
     output = _wrapper._execute_api('list', keys, **kwargs)
     return output
 
+
 def search(term, **kwargs):
     keys = [
         'term', 'num', 'lang',
@@ -97,34 +126,52 @@ def search(term, **kwargs):
     output = _wrapper._execute_api('search', keys,  **{'term': term, **kwargs})
     return output
 
+
 def developer(devId, **kwargs):
     keys = ['devId', 'lang', 'country', 'num', 'fullDetail']
-    output = _wrapper._execute_api('developer', keys,  **{'devId': devId, **kwargs})
+    output = _wrapper._execute_api(
+        'developer', keys,  **{'devId': devId, **kwargs})
     return output
 
+
 def suggest(term, **kwargs):
     keys = ['term', 'lang', 'country']
-    output = _wrapper._execute_api('suggest', keys,  **{'term': term, **kwargs})
+    output = _wrapper._execute_api(
+        'suggest', keys,  **{'term': term, **kwargs})
     return output
 
+
 def reviews(appId, **kwargs):
     keys = [
         'appId', 'lang', 'country', 'sort',
         'num', 'paginate', 'nextPaginationToken'
     ]
-    output = _wrapper._execute_api('reviews', keys,  **{'appId': appId, **kwargs})
+    output = _wrapper._execute_api(
+        'reviews', keys,  **{'appId': appId, **kwargs})
     return output
 
+
 def similar(appId, **kwargs):
     keys = ['appId', 'lang', 'country', 'fullDetail']
-    output = _wrapper._execute_api('similar', keys,  **{'appId': appId, **kwargs})
+    output = _wrapper._execute_api(
+        'similar', keys,  **{'appId': appId, **kwargs})
     return output
 
+
 def permissions(appId, **kwargs):
     keys = ['appId', 'lang', 'short']
-    output = _wrapper._execute_api('permissions', keys,  **{'appId': appId, **kwargs})
+    output = _wrapper._execute_api(
+        'permissions', keys,  **{'appId': appId, **kwargs})
     return output
 
+
+def datasafety(appId, **kwargs):
+    keys = ['appId', 'lang']
+    output = _wrapper._execute_api(
+        'datasafety', keys,  **{'appId': appId, **kwargs})
+    return output
+
+
 def categories(**kwargs):
     output = _wrapper._execute_api('categories', [],  **kwargs)
     return output
